summaryrefslogtreecommitdiffstats
path: root/kword/KWTextFrameSet.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /kword/KWTextFrameSet.h
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kword/KWTextFrameSet.h')
-rw-r--r--kword/KWTextFrameSet.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kword/KWTextFrameSet.h b/kword/KWTextFrameSet.h
index 7cc4efb5..aee28007 100644
--- a/kword/KWTextFrameSet.h
+++ b/kword/KWTextFrameSet.h
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
* into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
/** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
KWFrame * internalToDocument( const KoPoint &relPoint, KoPoint &dPoint ) const;
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
* Returns a point in tqlayout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -237,7 +237,7 @@ public:
#endif
/** Invalidate all paragraphs and start re-formatting */
- virtual void tqlayout();
+ virtual void layout();
/** Invalidate all paragraphs (causes a re-flow of the text upon next redraw) */
virtual void invalidate();
@@ -275,13 +275,13 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
/** Let KoTextFormatInterface access the current parag tqlayout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;
- /** Let KoTextFormatInterface set a modified current parag tqlayout */
+ /** Let KoTextFormatInterface set a modified current parag layout */
virtual KCommand *setParagLayoutFormatCommand( KoParagLayout *newLayout, int flags, int marginIndex=-1);
virtual KCommand *setChangeCaseOfTextCommand(KoChangeCaseDia::TypeOfCase _type);
@@ -93,14 +93,14 @@ public:
void clearUndoRedoInfo();
/** Convert the @p dPoint in the normal coordinate system (and in pt)
- * into a point (@p iPoint) in the internal qtextdoc coordinates (in tqlayout units). */
+ * into a point (@p iPoint) in the internal qtextdoc coordinates (in layout units). */
KWFrame * documentToInternal( const KoPoint &dPoint, TQPoint &iPoint ) const;
/// used by documentToInternalMouseSelection()
@@ -93,14 +93,14 @@ public:
enum RelativePosition { InsideFrame, LeftOfFrame, TopOfFrame, AtEnd };
KWFrame * documentToInternalMouseSelection( const KoPoint &dPoint, TQPoint &iPoint, RelativePosition& relPos, KWViewMode *viewMode ) const;
- /** Convert the @p in the internal qtextdoc coordinates (in tqlayout units)
+ /** Convert the @p in the internal qtextdoc coordinates (in layout units)
* into a point in the document coordinate system (in pt).
* Also returns the frame in which this point is. */
@@ -125,7 +125,7 @@ public:
KoPoint internalToDocumentKnowingFrame( const TQPoint &iPoint, KWFrame* theFrame ) const;
/** Implementation of Ctrl+PageUp/PageDown
- * Returns a point in tqlayout units (for placing the cursor) */
+ * Returns a point in layout units (for placing the cursor) */
TQPoint moveToPage( int currentPgNum, short int direction ) const;
/** Return the available height in pixels (sum of all frames' height, with zoom applied)
@@ -275,13 +275,13 @@ public:
/** Let KoTextFormatInterface set the modified format */
virtual KCommand *setFormatCommand( const KoTextFormat * newFormat, int flags, bool zoomFont = false );
- /** Let KoTextFormatInterface access the current parag tqlayout */
+ /** Let KoTextFormatInterface access the current parag layout */
virtual const KoParagLayout * currentParagLayoutFormat() const;
virtual bool rtl() const ;